Examples
========

Simple
------

.. literalinclude:: ../examples/graphs.py
   :language: python

Color
-----

.. literalinclude:: ../examples/color_graphs.py
   :language: python

Multicolor
----------

.. literalinclude:: ../examples/color_multivalue_graphs.py
   :language: python

Human Readable
--------------

.. literalinclude:: ../examples/human_readable.py
   :language: python

Shell Scripts
--------------

.. literalinclude:: ../examples/loadtop.sh
   :language: bash

.. literalinclude:: ../examples/gdu.sh
   :language: bash
